from .theme import Theme

__all__ = ["Theme"]

__author__ = "frissyn"
__version__ = "0.2.0"
__doc__ = "Python package for creating IDE themes on Repl.it"
